.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.md
   :parser: myst_parser.sphinx_

Contents:
=========

.. toctree::
   :maxdepth: 2

   installation
   usage
   examples
   esub
   contributing
   authors
   history

Feedback
========

If you have any suggestions or questions about esub feel free to email me
at dominik.zuercher@phys.ethz.ch.

If you encounter any errors or problems with esub, please let me know!
